import os

import click

from pylista.defaults import LISTS_DIR
from pylista.lists import (add_note_to_list, create_json_file,
                           get_notes_from_list, print_notes,
                           remove_note_from_list)


@click.group()
def cli():
    """A simple CLI tool to manage lists"""
    pass


@cli.command()
@click.argument("list")
@click.argument("note")
def add(list, note):
    """Add a note to list"""
    list_path = _make_path_to_list(list)

    if not os.path.exists(list_path):
        click.secho("\nList doesn't exist!\n", fg="yellow")
    else:
        add_note_to_list(note, list_path)
        click.secho(f"\nNote added to list {list}\n", fg="green")


@cli.command()
@click.argument("list")
@click.argument("id")
def rm(list, id):
    """Remove a note from list"""
    list_path = _make_path_to_list(list)
    try:
        remove_note_from_list(int(id), list_path)
        click.secho(f"\nRemoved note {id} from list {list}\n", fg="green")
    except IndexError:
        click.secho("\nNote doesn't exist!\n", fg="yellow")


@cli.command()
@click.argument("list")
def ls(list):
    """List notes"""
    list_path = _make_path_to_list(list)

    if not os.path.exists(list_path):
        click.secho("\nList does not exists!\n", fg="yellow")
    else:
        notes = get_notes_from_list(list_path)
        print_notes(notes)


@cli.command()
@click.argument("list")
def newls(list):
    """
    Create a new list
    """
    new_list = os.path.join(LISTS_DIR, f"{list}.json")

    if os.path.exists(new_list):
        click.secho("List is already present!")
    else:
        path = create_json_file(list)
        click.secho(f"\nList created: {path}\n", fg="green")


def _make_path_to_list(list: str) -> str:
    return os.path.join(LISTS_DIR, f"{list}.json")



import json
import os

from pylista.defaults import LISTS_DIR


def create_json_file(list_name: str) -> str:
    """
    Create a json file if it does not exist
    """
    if not os.path.exists(LISTS_DIR):
        os.makedirs(LISTS_DIR)

    path = os.path.join(LISTS_DIR, list_name)
    data = {"notes": []}
    with open(f"{path}.json", "w+") as f:
        json.dump(data, f)
    return path


def add_note_to_list(note: str, list_path: str) -> None:
    """
    Add note to list
    """
    with open(list_path, "r+") as json_file:
        data = json.load(json_file)
        data["notes"].append(note)
        json_file.seek(0)
        json.dump(data, json_file)


def get_notes_from_list(list_path: str) -> list:
    """
    Get and returns a python list containing notes from a list file
    """
    with open(list_path, "r") as json_file:
        data = json.load(json_file)
    return data["notes"]


def print_notes(list_obj: list) -> None:
    """
    Format a python list of notes to print
    """
    print("\n")
    if len(list_obj) == 0:
        print("List is empty\n")
    for i, l in enumerate(list_obj):
        print(f"  {i}: {l}\n")


def remove_note_from_list(id: int, list_path: str) -> None:
    """
    Remove a note from list by id
    """
    with open(list_path, "r+") as json_file:
        data = json.load(json_file)
        del data["notes"][id]
        json_file.seek(0)
        json.dump(data, json_file)
        json_file.truncate()
